@@ -30,7 +30,7 @@ class AbstractJob(HookMixin, ProfileMixin, MetadataMixin):
         """
         :param _id: a unique id, if None is given then one will be assigned when this job is added to a :py:class:`~Pegasus.api.workflow.Workflow`, defaults to None
         :type _id: Optional[str]
-        :param node_label: a short descriptive label that can be assigned to this job, defaults to None 
+        :param node_label: a short descriptive label that can be assigned to this job, defaults to None
         :type node_label: Optional[str]
 
         **Note**: avoid using IDs such as :code:`'0000008'` or :code:`'00000009'` as these may end up being
@@ -47,15 +47,15 @@ class AbstractJob(HookMixin, ProfileMixin, MetadataMixin):
         self.stdin = None
 
         self.hooks = defaultdict(list)
-        self.profiles = defaultdict(dict)
-        self.metadata = dict()
+        self.profiles = defaultdict(OrderedDict)
+        self.metadata = OrderedDict()
 
     @_chained
     def add_inputs(self, *input_files: Union[File, str], bypass_staging: bool = False):
         """
         add_inputs(self, *input_files: Union[File, str], bypass: bool = False)
         Add one or more :py:class:`~Pegasus.api.replica_catalog.File` objects as input to this job.
-        If :code:`input_file` is given as a str, a :py:class:`~Pegasus.api.replica_catalog.File` object is created for 
+        If :code:`input_file` is given as a str, a :py:class:`~Pegasus.api.replica_catalog.File` object is created for
         you internally with the given value as its lfn.
 
         :param input_files: the :py:class:`~Pegasus.api.replica_catalog.File` objects to be added as inputs to this job
@@ -112,7 +112,7 @@ class AbstractJob(HookMixin, ProfileMixin, MetadataMixin):
         add_outputs(self, *output_files: Union[File, str], stage_out: bool = True, register_replica: bool = True)
         Add one or more :py:class:`~Pegasus.api.replica_catalog.File` objects as outputs to this job. :code:`stage_out` and :code:`register_replica`
         will be applied to all files given.
-        If :code:`output_file` is given as a str, a :py:class:`~Pegasus.api.replica_catalog.File` object is created for 
+        If :code:`output_file` is given as a str, a :py:class:`~Pegasus.api.replica_catalog.File` object is created for
         you internally with the given value as its lfn.
 
         :param output_files: the :py:class:`~Pegasus.api.replica_catalog.File` objects to be added as outputs to this job
@@ -169,7 +169,7 @@ class AbstractJob(HookMixin, ProfileMixin, MetadataMixin):
         """
         add_checkpoint(self, checkpoint_file: Union[File, str], stage_out: bool = True, register_replica: bool = True)
         Add an output :py:class:`~Pegasus.api.replica_catalog.File` of this job as a checkpoint file
-        If :code:`checkpoint_file` is given as a str, a :py:class:`~Pegasus.api.replica_catalog.File` object is created for 
+        If :code:`checkpoint_file` is given as a str, a :py:class:`~Pegasus.api.replica_catalog.File` object is created for
         you internally with the given value as its lfn.
 
         :param checkpoint_file: the :py:class:`~Pegasus.api.replica_catalog.File` to be added as a checkpoint file to this job
@@ -356,25 +356,41 @@ class AbstractJob(HookMixin, ProfileMixin, MetadataMixin):
 
     def __json__(self):
         return _filter_out_nones(
-            {
-                "id": self._id,
-                "stdin": self.stdin.lfn if self.stdin is not None else None,
-                "stdout": self.stdout.lfn if self.stdout is not None else None,
-                "stderr": self.stderr.lfn if self.stderr is not None else None,
-                "nodeLabel": self.node_label,
-                "arguments": [
-                    arg.lfn if isinstance(arg, File) else arg for arg in self.args
-                ],
-                "uses": [use for use in self.uses],
-                "profiles": dict(self.profiles) if len(self.profiles) > 0 else None,
-                "metadata": self.metadata if len(self.metadata) > 0 else None,
-                "hooks": {
-                    hook_name: [hook for hook in values]
-                    for hook_name, values in self.hooks.items()
-                }
-                if len(self.hooks) > 0
-                else None,
-            }
+            OrderedDict(
+                [
+                    ("id", self._id),
+                    ("stdin", self.stdin.lfn if self.stdin is not None else None),
+                    ("stdout", self.stdout.lfn if self.stdout is not None else None),
+                    ("stderr", self.stderr.lfn if self.stderr is not None else None),
+                    ("nodeLabel", self.node_label),
+                    (
+                        "arguments",
+                        [
+                            arg.lfn if isinstance(arg, File) else arg
+                            for arg in self.args
+                        ],
+                    ),
+                    ("uses", [use for use in self.uses]),
+                    (
+                        "profiles",
+                        OrderedDict(sorted(self.profiles.items(), key=lambda _: _[0]))
+                        if len(self.profiles) > 0
+                        else None,
+                    ),
+                    ("metadata", self.metadata if len(self.metadata) > 0 else None),
+                    (
+                        "hooks",
+                        OrderedDict(
+                            [
+                                (hook_name, [hook for hook in values])
+                                for hook_name, values in self.hooks.items()
+                            ]
+                        )
+                        if len(self.hooks) > 0
+                        else None,
+                    ),
+                ]
+            )
         )
 
 
@@ -440,12 +456,14 @@ class Job(AbstractJob):
         AbstractJob.__init__(self, _id=_id, node_label=node_label)
 
     def __json__(self):
-        job_json = {
-            "type": "job",
-            "namespace": self.namespace,
-            "version": self.version,
-            "name": self.transformation,
-        }
+        job_json = OrderedDict(
+            [
+                ("type", "job"),
+                ("namespace", self.namespace),
+                ("version", self.version),
+                ("name", self.transformation),
+            ]
+        )
 
         job_json.update(AbstractJob.__json__(self))
 
@@ -492,7 +510,7 @@ class SubWorkflow(AbstractJob):
         # Upon invoking root_wf.write() or root_wf.plan(), another_wf will automatically
         # be serialized to CWD / "another-wf_j2.yml" and added to an inline ReplicaCatalog;
         # This means that you may define "another_wf" in a separate python script, and
-        # import it here where it would be used. 
+        # import it here where it would be used.
         root_wf.write()
     """
 
@@ -569,9 +587,9 @@ class SubWorkflow(AbstractJob):
     ):
         r"""
         add_planner_args(self, conf: Optional[Union[str, Path]] = None, basename: Optional[str] = None, job_prefix: Optional[str] = None, cluster: Optional[List[str]] = None, sites: Optional[List[str]] = None, output_sites: Optional[List[str]] = None, staging_sites: Optional[Dict[str, str]] = None, cache: Optional[List[Union[str, Path]]] = None, input_dirs: Optional[List[str]] = None, output_dir: Optional[str] = None, dir: Optional[str] = None, relative_dir: Optional[Union[str, Path]] = None, random_dir: Union[bool, str, Path] = False, relative_submit_dir: Optional[Union[str, Path]] = None, inherited_rc_files: Optional[List[Union[str, Path]]] = None, cleanup: Optional[str] = None, reuse: Optional[List[Union[str,Path]]] = None, verbose: int = 0, quiet: int = 0, force: bool = False, force_replan: bool = False, forward: Optional[List[str]] = None, submit: bool = False, json: bool = False, java_options: Optional[List[str]] = None, **properties: Dict[str, str])
-        Add pegasus-planner arguments. This function can only be used when 
+        Add pegasus-planner arguments. This function can only be used when
         :code:`is_planned=False` is set in :py:class:`~Pegasus.api.workflow.SubWorkflow` and
-        may only be invoked once. 
+        may only be invoked once.
 
         :param conf:  the path to the properties file to use for planning, defaults to None
         :type conf: Optional[Union[str, Path]]
@@ -790,7 +808,7 @@ class SubWorkflow(AbstractJob):
         if isinstance(self.file, Workflow):
             raise PegasusError("the given SubWorkflow file must be a File object")
 
-        dax_json = {"type": self.type, "file": self.file}
+        dax_json = OrderedDict([("type", self.type), ("file", self.file)])
         dax_json.update(AbstractJob.__json__(self))
 
         return dax_json
@@ -870,15 +888,20 @@ class _Use:
 
     def __json__(self):
         return _filter_out_nones(
-            {
-                "lfn": self.file.lfn,
-                "metadata": self.file.metadata if len(self.file.metadata) > 0 else None,
-                "size": self.file.size,
-                "type": self._type,
-                "stageOut": self.stage_out,
-                "registerReplica": self.register_replica,
-                "bypass": self.bypass,
-            }
+            OrderedDict(
+                [
+                    ("lfn", self.file.lfn),
+                    (
+                        "metadata",
+                        self.file.metadata if len(self.file.metadata) > 0 else None,
+                    ),
+                    ("size", self.file.size),
+                    ("type", self._type),
+                    ("stageOut", self.stage_out),
+                    ("registerReplica", self.register_replica),
+                    ("bypass", self.bypass),
+                ]
+            )
         )
 
 
@@ -900,7 +923,9 @@ class _JobDependency:
         )
 
     def __json__(self):
-        return {"id": self.parent_id, "children": list(self.children_ids)}
+        return OrderedDict(
+            [("id", self.parent_id), ("children", list(self.children_ids))]
+        )
 
 
 def _needs_client(f):
@@ -983,7 +1008,7 @@ class Workflow(Writable, HookMixin, ProfileMixin, MetadataMixin):
 
         # --- Workflow -----------------------------------------------------------------
         '''
-                            [f.b1] - (findrange) - [f.c1] 
+                            [f.b1] - (findrange) - [f.c1]
                             /                             \\
         [f.a] - (preprocess)                               (analyze) - [f.d]
                             \\                             /
@@ -1069,7 +1094,7 @@ class Workflow(Writable, HookMixin, ProfileMixin, MetadataMixin):
         # sequence unique to this workflow only
         self.sequence = 1
 
-        self.jobs = dict()
+        self.jobs = OrderedDict()
         self.dependencies = defaultdict(_JobDependency)
 
         self.site_catalog = None
@@ -1077,8 +1102,8 @@ class Workflow(Writable, HookMixin, ProfileMixin, MetadataMixin):
         self.replica_catalog = None
 
         self.hooks = defaultdict(list)
-        self.profiles = defaultdict(dict)
-        self.metadata = dict()
+        self.profiles = defaultdict(OrderedDict)
+        self.metadata = OrderedDict()
 
     @property
     @_needs_submit_dir
@@ -1347,17 +1372,17 @@ class Workflow(Writable, HookMixin, ProfileMixin, MetadataMixin):
                     }
                 }
             }
-    
+
         Keys are defined as follows
-            * :code:`unready`: Jobs blocked by dependencies 
-            * :code:`ready`: Jobs ready for submission 
-            * :code:`pre`: PRE-Scripts running 
-            * :code:`queued`: Submitted jobs 
-            * :code:`post`: POST-Scripts running 
-            * :code:`succeeded`: Job completed with success 
-            * :code:`failed`: Jobs completed with failure 
+            * :code:`unready`: Jobs blocked by dependencies
+            * :code:`ready`: Jobs ready for submission
+            * :code:`pre`: PRE-Scripts running
+            * :code:`queued`: Submitted jobs
+            * :code:`post`: POST-Scripts running
+            * :code:`succeeded`: Job completed with success
+            * :code:`failed`: Jobs completed with failure
             * :code:`percent_done`: Success percentage
-            * :code:`state`: Workflow state 
+            * :code:`state`: Workflow state
             * :code:`dagname`: Name of workflow
 
         :return: current status information
@@ -1723,7 +1748,7 @@ class Workflow(Writable, HookMixin, ProfileMixin, MetadataMixin):
 
         if self.infer_dependencies:
             log.info("inferring {workflow} dependencies".format(workflow=self.name))
-            mapping = dict()
+            mapping = OrderedDict()
 
             """
             create a mapping:
@@ -1880,14 +1905,16 @@ class Workflow(Writable, HookMixin, ProfileMixin, MetadataMixin):
 
         hooks = None
         if len(self.hooks) > 0:
-            hooks = {
-                hook_name: [hook for hook in values]
-                for hook_name, values in self.hooks.items()
-            }
+            hooks = OrderedDict(
+                [
+                    (hook_name, [hook for hook in values])
+                    for hook_name, values in self.hooks.items()
+                ]
+            )
 
         profiles = None
         if len(self.profiles) > 0:
-            profiles = dict(self.profiles)
+            profiles = OrderedDict(sorted(self.profiles.items(), key=lambda _: _[0]))
 
         metadata = None
         if len(self.metadata) > 0:
